==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/style/values/motion/StyleOffsetAnchor.cpp <==
/*
 * Copyright (C) 2025 Samuel Weinig <sam@webkit.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "StyleOffsetAnchor.h"

#include "CSSPositionValue.h"
#include "RenderStyleInlines.h"
#include "StyleBuilderChecking.h"
#include "StyleLengthWrapper+Blending.h"
#include "StylePrimitiveNumericTypes+Blending.h"
#include <wtf/text/TextStream.h>

namespace WebCore {
namespace Style {

#if ENABLE(THREADED_ANIMATIONS)

auto OffsetAnchor::convert(const AcceleratedEffectOffsetAnchor& value) -> Variant<CSS::Keyword::Auto, Position>
{
    if (!value.value)
        return CSS::Keyword::Auto { };
    return Position { *value.value };
}

#endif

// MARK: - Conversion

auto CSSValueConversion<OffsetAnchor>::operator()(BuilderState& state, const CSSValue& value) -> OffsetAnchor
{
    if (value.valueID() == CSSValueAuto)
        return OffsetAnchor { CSS::Keyword::Auto { } };

    RefPtr positionValue = requiredDowncast<CSSPositionValue>(state, value);
    if (!positionValue)
        return RenderStyle::initialOffsetAnchor();
    return OffsetAnchor { toStyle(positionValue->position(), state) };
}

// MARK: - Blending

auto Blending<OffsetAnchor>::canBlend(const OffsetAnchor& a, const OffsetAnchor& b) -> bool
{
    return a.isPosition() && b.isPosition();
}

auto Blending<OffsetAnchor>::requiresInterpolationForAccumulativeIteration(const OffsetAnchor& a, const OffsetAnchor& b) -> bool
{
    ASSERT(canBlend(a, b));
    return Style::requiresInterpolationForAccumulativeIteration(*a.tryPosition(), *b.tryPosition());
}

auto Blending<OffsetAnchor>::blend(const OffsetAnchor& a, const OffsetAnchor& b, const BlendingContext& context) -> OffsetAnchor
{
    if (context.isDiscrete) {
        ASSERT(!context.progress || context.progress == 1.0);
        return context.progress ? b : a;
    }

    ASSERT(canBlend(a, b));
    return OffsetAnchor { Style::blend(*a.tryPosition(), *b.tryPosition(), context) };
}

// MARK: - Evaluation

#if ENABLE(THREADED_ANIMATIONS)

auto Evaluation<OffsetAnchor, AcceleratedEffectOffsetAnchor>::operator()(const OffsetAnchor& value, FloatSize referenceBox, ZoomNeeded token) -> AcceleratedEffectOffsetAnchor
{
    return WTF::switchOn(value,
        [&](const Position& position) -> AcceleratedEffectOffsetAnchor {
            return { .value = evaluate<FloatPoint>(position, referenceBox, token) };
        },
        [](const CSS::Keyword::Auto&) -> AcceleratedEffectOffsetAnchor {
            return { .value = std::nullopt };
        }
    );
}

#endif

} // namespace Style
} // namespace WebCore

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebCore/style/values/motion/StyleOffsetAnchor.cpp <==
/*
 * Copyright (C) 2025 Samuel Weinig <sam@webkit.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "StyleOffsetAnchor.h"

#include "CSSPositionValue.h"
#include "StyleBuilderChecking.h"
#include "StyleComputedStyle+InitialInlines.h"
#include "StyleLengthWrapper+Blending.h"
#include "StylePrimitiveNumericTypes+Blending.h"
#include <wtf/text/TextStream.h>

namespace WebCore {
namespace Style {

#if ENABLE(THREADED_ANIMATIONS)

auto OffsetAnchor::convert(const AcceleratedEffectOffsetAnchor& value) -> Variant<CSS::Keyword::Auto, Position>
{
    if (!value.value)
        return CSS::Keyword::Auto { };
    return Position { *value.value };
}

#endif

// MARK: - Conversion

auto CSSValueConversion<OffsetAnchor>::operator()(BuilderState& state, const CSSValue& value) -> OffsetAnchor
{
    if (value.valueID() == CSSValueAuto)
        return OffsetAnchor { CSS::Keyword::Auto { } };

    RefPtr positionValue = requiredDowncast<CSSPositionValue>(state, value);
    if (!positionValue)
        return Style::ComputedStyle::initialOffsetAnchor();
    return OffsetAnchor { toStyle(positionValue->position(), state) };
}

// MARK: - Blending

auto Blending<OffsetAnchor>::canBlend(const OffsetAnchor& a, const OffsetAnchor& b) -> bool
{
    return a.isPosition() && b.isPosition();
}

auto Blending<OffsetAnchor>::requiresInterpolationForAccumulativeIteration(const OffsetAnchor& a, const OffsetAnchor& b) -> bool
{
    ASSERT(canBlend(a, b));
    return Style::requiresInterpolationForAccumulativeIteration(*a.tryPosition(), *b.tryPosition());
}

auto Blending<OffsetAnchor>::blend(const OffsetAnchor& a, const OffsetAnchor& b, const BlendingContext& context) -> OffsetAnchor
{
    if (context.isDiscrete) {
        ASSERT(!context.progress || context.progress == 1.0);
        return context.progress ? b : a;
    }

    ASSERT(canBlend(a, b));
    return OffsetAnchor { Style::blend(*a.tryPosition(), *b.tryPosition(), context) };
}

// MARK: - Evaluation

#if ENABLE(THREADED_ANIMATIONS)

auto Evaluation<OffsetAnchor, AcceleratedEffectOffsetAnchor>::operator()(const OffsetAnchor& value, FloatSize referenceBox, ZoomNeeded token) -> AcceleratedEffectOffsetAnchor
{
    return WTF::switchOn(value,
        [&](const Position& position) -> AcceleratedEffectOffsetAnchor {
            return { .value = evaluate<FloatPoint>(position, referenceBox, token) };
        },
        [](const CSS::Keyword::Auto&) -> AcceleratedEffectOffsetAnchor {
            return { .value = std::nullopt };
        }
    );
}

#endif

} // namespace Style
} // namespace WebCore
